# Changelog

<!--
   You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst
-->

<!-- towncrier release notes start -->

## 1.0.0a2 (2026-02-20)


### New features:

- Add plone.restapi sync endpoints (@sync-keycloak, @sync-keycloak-groups, @sync-keycloak-users). 

## 1.0.0a1 (2026-02-19)


### New features:

- Initial release. Extracted from 7inOne as a standalone package. [#1](https://github.com/webcloud7/wcs.keycloak/issues/1)
